==> ldkit-0.6.0.tgz: package/esm/library/engine/query_engine.js <==
import { BindingsFactory, QuadFactory, } from "../rdf.js";
import { ArrayIterator, MappingIterator } from "../asynciterator.js";
export class QueryEngine {
    getSparqlEndpoint(context) {
        if (!context) {
            throw new Error("No context supplied to QueryEngine. You need to create a default context or pass one to a resource.");
        }
        if (!Array.isArray(context.sources) || context.sources.length < 1) {
            throw new Error("Invalid context `sources` attribute defined. You need to provide a URL to a SPARQL endpoint to query.");
        }
        if (context.sources.length > 1) {
            throw new Error("This query engine supports only one data source, multiple defined in `sources` property in context.");
        }
        const source = context.sources[0];
        if (typeof source === "string") {
            return source;
        }
        if ("value" in source && typeof source.value === "string") {
            if ("type" in source) {
                if (source.type === "sparql") {
                    return source.value;
                }
            }
            else {
                return source.value;
            }
        }
        throw new Error("Invalid SPARQL source defined - please provide URL to a SPARQL endpoint to query.");
    }
    getFetch(context) {
        return context && context.fetch ? context.fetch : fetch;
    }
    async query(query, context) {
        const endpoint = this.getSparqlEndpoint(context);
        const fetchFn = this.getFetch(context);
        return await fetchFn(endpoint, {
            method: "POST",
            headers: {
                "accept": "application/sparql-results+json",
                "content-type": "application/x-www-form-urlencoded; charset=UTF-8",
            },
            body: new URLSearchParams({
                query,
            }),
        });
    }
    async queryBindings(query, context) {
        const result = await this.query(query, context);
        const json = await result.json();
        if (!Array.isArray(json?.results?.bindings)) {
            throw new Error("Bindings SPARQL query result not found");
        }
        const bindingsFactory = new BindingsFactory();
        const bindingsIterator = new ArrayIterator(json.results.bindings);
        // TODO: review the unknown type cast
        return new MappingIterator(bindingsIterator, (i) => bindingsFactory.fromJson(i));
    }
    async queryBoolean(query, context) {
        const result = await this.query(query, context);
        const json = await result.json();
        if ("boolean" in json) {
            return Boolean(json.boolean);
        }
        throw new Error("Boolean SPARQL query result not found");
    }
    async queryQuads(query, context) {
        const result = await this.query(query, context);
        const json = await result.json();
        if (!Array.isArray(json?.results?.bindings)) {
            throw new Error("Quads SPARQL query result not found");
        }
        const quadFactory = new QuadFactory();
        const bindingsIterator = new ArrayIterator(json.results.bindings);
        // TODO: review the unknown type cast
        return new MappingIterator(bindingsIterator, (i) => quadFactory.fromJson(i));
    }
    async queryVoid(query, context) {
        await this.query(query, context);
    }
}

==> ldkit-0.6.2.tgz: package/esm/library/engine/query_engine.js <==
import { BindingsFactory, QuadFactory, } from "../rdf.js";
import { ArrayIterator, MappingIterator, TreeIterator, } from "../asynciterator.js";
export class QueryEngine {
    getSparqlEndpoint(context) {
        if (!context) {
            throw new Error("No context supplied to QueryEngine. You need to create a default context or pass one to a resource.");
        }
        if (!Array.isArray(context.sources) || context.sources.length < 1) {
            throw new Error("Invalid context `sources` attribute defined. You need to provide a URL to a SPARQL endpoint to query.");
        }
        if (context.sources.length > 1) {
            throw new Error("This query engine supports only one data source, multiple defined in `sources` property in context.");
        }
        const source = context.sources[0];
        if (typeof source === "string") {
            return source;
        }
        if ("value" in source && typeof source.value === "string") {
            if ("type" in source) {
                if (source.type === "sparql") {
                    return source.value;
                }
            }
            else {
                return source.value;
            }
        }
        throw new Error("Invalid SPARQL source defined - please provide URL to a SPARQL endpoint to query.");
    }
    getFetch(context) {
        return context && context.fetch ? context.fetch : fetch;
    }
    async query(query, responseType, context) {
        const endpoint = this.getSparqlEndpoint(context);
        const fetchFn = this.getFetch(context);
        const response = await fetchFn(endpoint, {
            method: "POST",
            headers: {
                "accept": responseType,
                "content-type": "application/x-www-form-urlencoded; charset=UTF-8",
            },
            body: new URLSearchParams({
                query,
            }),
        });
        const json = await response.json();
        return json;
    }
    async queryBindings(query, context) {
        const json = await this.query(query, "application/sparql-results+json", context);
        if (!Array.isArray(json.results?.bindings)) {
            throw new Error("Bindings SPARQL query result not found");
        }
        const bindingsFactory = new BindingsFactory();
        const bindingsIterator = new ArrayIterator(json.results.bindings);
        // TODO: review the unknown type cast
        return new MappingIterator(bindingsIterator, (i) => bindingsFactory.fromJson(i));
    }
    async queryBoolean(query, context) {
        const json = await this.query(query, "application/sparql-results+json", context);
        if ("boolean" in json) {
            return Boolean(json.boolean);
        }
        throw new Error("Boolean SPARQL query result not found");
    }
    async queryQuads(query, context) {
        const json = await this.query(query, "application/rdf+json", context);
        if (!(json?.constructor === Object)) {
            throw new Error("Quads SPARQL query result not found");
        }
        const quadFactory = new QuadFactory();
        const treeIterator = new TreeIterator(json);
        // TODO: review the unknown type cast
        return new MappingIterator(treeIterator, (i) => quadFactory.fromJson(i));
    }
    async queryVoid(query, context) {
        await this.query(query, "application/sparql-results+json", context);
    }
}
